Package: debrief
Title: Text-Based Summaries for 'profvis' Profiling Data
Version: 0.1.0
Authors@R: c(
    person("Emil", "Hvitfeldt", , "emil.hvitfeldt@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"), comment = c(ROR = "03wc8by49"))
  )
Description: Provides text-based summaries and analysis tools for
    'profvis' profiling output. Designed for terminal workflows and
    artificial intelligence (AI) agent consumption, offering views
    including hotspot analysis, call
    trees, source context, caller/callee relationships, and memory
    allocation breakdowns.
License: MIT + file LICENSE
URL: https://github.com/r-lib/debrief, https://r-lib.github.io/debrief/
BugReports: https://github.com/r-lib/debrief/issues
Depends: R (>= 4.1)
Suggests: knitr, profvis, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-21 19:06:03 UTC; emilhvitfeldt
Author: Emil Hvitfeldt [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Emil Hvitfeldt <emil.hvitfeldt@posit.co>
Repository: CRAN
Date/Publication: 2026-04-21 21:22:26 UTC
Built: R 4.5.2; ; 2026-04-22 00:05:50 UTC; unix
