# Generated by roxygen2: do not edit by hand

S3method(print,debrief_call_depth)
S3method(print,debrief_call_stats)
S3method(print,debrief_callers_callees)
S3method(print,debrief_compare)
S3method(print,debrief_compare_many)
S3method(print,debrief_debrief)
S3method(print,debrief_file_summary)
S3method(print,debrief_flame)
S3method(print,debrief_flame_condense)
S3method(print,debrief_focus)
S3method(print,debrief_gc_pressure)
S3method(print,debrief_help)
S3method(print,debrief_hot_lines)
S3method(print,debrief_hot_paths)
S3method(print,debrief_memory)
S3method(print,debrief_recursive)
S3method(print,debrief_source_context)
S3method(print,debrief_suggestions)
export(pv_call_depth)
export(pv_call_stats)
export(pv_callees)
export(pv_callers)
export(pv_compare)
export(pv_compare_many)
export(pv_debrief)
export(pv_example)
export(pv_file_summary)
export(pv_flame)
export(pv_flame_condense)
export(pv_focus)
export(pv_gc_pressure)
export(pv_help)
export(pv_hot_lines)
export(pv_hot_paths)
export(pv_memory)
export(pv_memory_lines)
export(pv_print_call_depth)
export(pv_print_call_stats)
export(pv_print_callers_callees)
export(pv_print_compare)
export(pv_print_compare_many)
export(pv_print_debrief)
export(pv_print_file_summary)
export(pv_print_gc_pressure)
export(pv_print_hot_lines)
export(pv_print_hot_paths)
export(pv_print_memory)
export(pv_print_recursive)
export(pv_print_suggestions)
export(pv_recursive)
export(pv_self_time)
export(pv_source_context)
export(pv_suggestions)
export(pv_to_json)
export(pv_to_list)
export(pv_total_time)
export(pv_worst_line)
importFrom(utils,head)
