% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/file-summary.R
\name{pv_file_summary}
\alias{pv_file_summary}
\title{File-level time summary}
\usage{
pv_file_summary(x)
}
\arguments{
\item{x}{A profvis object.}
}
\value{
A data frame with columns:
\itemize{
\item \code{filename}: Source file path
\item \code{samples}: Number of profiling samples
\item \code{time_ms}: Time in milliseconds
\item \code{pct}: Percentage of total time
}
}
\description{
Aggregates profiling time by source file. Requires source references
(use \code{devtools::load_all()} for best results).
}
\examples{
p <- pv_example()
pv_file_summary(p)
}
