% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/call-depth.R
\name{pv_call_depth}
\alias{pv_call_depth}
\title{Call depth breakdown}
\usage{
pv_call_depth(x)
}
\arguments{
\item{x}{A profvis object.}
}
\value{
A data frame with columns:
\itemize{
\item \code{depth}: Call stack depth (1 = top level)
\item \code{samples}: Number of profiling samples at this depth
\item \code{time_ms}: Time in milliseconds
\item \code{pct}: Percentage of total time
\item \code{top_funcs}: Most common functions at this depth
}
}
\description{
Shows time distribution across different call stack depths. Useful for
understanding how deeply nested the hot code paths are.
}
\examples{
p <- pv_example()
pv_call_depth(p)
}
