% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/antipatterns.R
\name{pv_print_gc_pressure}
\alias{pv_print_gc_pressure}
\title{Print GC pressure analysis}
\usage{
pv_print_gc_pressure(x, threshold = 10)
}
\arguments{
\item{x}{A profvis object.}

\item{threshold}{Minimum GC percentage to report (default 10).}
}
\value{
Invisibly returns a \code{debrief_gc_pressure} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Print GC pressure analysis
}
\examples{
p <- pv_example("gc")
pv_print_gc_pressure(p)

}
