% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hot-lines.R
\name{pv_print_hot_lines}
\alias{pv_print_hot_lines}
\title{Print hot lines with source context}
\usage{
pv_print_hot_lines(x, n = 5, context = 3)
}
\arguments{
\item{x}{A profvis object.}

\item{n}{Number of hot lines to show.}

\item{context}{Number of lines to show before and after each hotspot.}
}
\value{
Invisibly returns a \code{debrief_hot_lines} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Prints the hot source lines along with surrounding code context.
}
\examples{
p <- pv_example()
pv_print_hot_lines(p, n = 5, context = 3)
}
