% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/debrief-package.R
\docType{package}
\name{debrief-package}
\alias{debrief}
\alias{debrief-package}
\title{debrief: Text-Based Summaries for 'profvis' Profiling Data}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides text-based summaries and analysis tools for 'profvis' profiling output. Designed for terminal workflows and artificial intelligence (AI) agent consumption, offering views including hotspot analysis, call trees, source context, caller/callee relationships, and memory allocation breakdowns.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/r-lib/debrief}
  \item \url{https://r-lib.github.io/debrief/}
  \item Report bugs at \url{https://github.com/r-lib/debrief/issues}
}

}
\author{
\strong{Maintainer}: Emil Hvitfeldt \email{emil.hvitfeldt@posit.co}

Other contributors:
\itemize{
  \item Posit Software, PBC (\href{https://ror.org/03wc8by49}{ROR}) [copyright holder, funder]
}

}
\keyword{internal}
