% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare.R
\name{pv_print_compare_many}
\alias{pv_print_compare_many}
\title{Print comparison of multiple profiles}
\usage{
pv_print_compare_many(...)
}
\arguments{
\item{...}{Named profvis objects to compare, or a single named list.}
}
\value{
Invisibly returns a \code{debrief_compare_many} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Print comparison of multiple profiles
}
\examples{
p1 <- pv_example()
p2 <- pv_example("gc")
pv_print_compare_many(baseline = p1, gc_heavy = p2)
}
