% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/callers-callees.R
\name{pv_print_callers_callees}
\alias{pv_print_callers_callees}
\title{Print caller/callee analysis for a function}
\usage{
pv_print_callers_callees(x, func, n = 10)
}
\arguments{
\item{x}{A profvis object.}

\item{func}{The function name to analyze.}

\item{n}{Maximum number of callers/callees to show.}
}
\value{
Invisibly returns a \code{debrief_callers_callees} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Shows both callers (who calls this function) and callees (what this function
calls) in a single view.
}
\examples{
p <- pv_example()
pv_print_callers_callees(p, "inner")
}
