% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export.R
\name{pv_to_list}
\alias{pv_to_list}
\title{Export profiling results as a list}
\usage{
pv_to_list(
  x,
  include = c("summary", "self_time", "total_time", "hot_lines", "memory", "gc_pressure",
    "suggestions", "recursive"),
  system_info = FALSE
)
}
\arguments{
\item{x}{A profvis object.}

\item{include}{Character vector specifying which analyses to include.
Same options as \code{\link[=pv_to_json]{pv_to_json()}}.}

\item{system_info}{If \code{TRUE}, includes R version and platform info in
metadata.}
}
\value{
A named list containing the requested analyses.
}
\description{
Returns all profiling analysis results as a nested R list, useful for
programmatic access to results without JSON serialization.
}
\examples{
p <- pv_example()
results <- pv_to_list(p)
names(results)
results$self_time

}
