% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare.R
\name{pv_print_compare}
\alias{pv_print_compare}
\title{Print profile comparison}
\usage{
pv_print_compare(before, after, n = 15)
}
\arguments{
\item{before}{A profvis object (before optimization).}

\item{after}{A profvis object (after optimization).}

\item{n}{Number of functions to show in detailed comparison.}
}
\value{
Invisibly returns a \code{debrief_compare} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Print profile comparison
}
\examples{
p1 <- pv_example()
p2 <- pv_example()
pv_print_compare(p1, p2)

}
