% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/memory.R
\name{pv_print_memory}
\alias{pv_print_memory}
\title{Print memory allocation summary}
\usage{
pv_print_memory(x, n = 10, by = c("function", "line"))
}
\arguments{
\item{x}{A profvis object.}

\item{n}{Number of top allocators to show.}

\item{by}{Either "function" or "line".}
}
\value{
Invisibly returns a \code{debrief_memory} object. Use
\code{capture.output()} to capture the formatted text output.
}
\description{
Print memory allocation summary
}
\examples{
p <- pv_example()
pv_print_memory(p, by = "function")
pv_print_memory(p, by = "line")

}
